export class STVersion {
    constructor(version) {
        Object.defineProperty(this, "version", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "_major", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "_minor", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "_patch", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "_rc", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        this.version = version.startsWith('v') ? version.slice(1) : version;
        this._rc = parseInt(version.split('rc')[1] || '0') || null;
        const verParts = this.version.split('.');
        this._major = parseInt(verParts[0] || '0');
        this._minor = parseInt(verParts[1] || '0') || null;
        this._patch = parseInt(verParts[2] || '0') || null;
    }
    bump(level) {
        return this[level]().toString();
    }
    major() {
        this._major++;
        if (this._minor !== null) {
            this._minor = 0;
            if (this._patch !== null) {
                this._patch = 0;
            }
        }
        this._rc = null;
        return this;
    }
    minor() {
        if (this._minor === null) {
            this._minor = 1;
        }
        else {
            this._minor++;
        }
        if (this._patch !== null) {
            this._patch = 0;
        }
        this._rc = null;
        return this;
    }
    patch() {
        if (this._minor === null) {
            this._minor = 0;
        }
        if (this._patch === null) {
            this._patch = 1;
        }
        else {
            this._patch++;
        }
        this._rc = null;
        return this;
    }
    rc() {
        if (this._minor === null) {
            this._minor = 0;
        }
        if (this._patch === null) {
            this._patch = 0;
        }
        if (this._rc === null) {
            this._rc = 1;
        }
        else {
            this._rc++;
        }
        return this;
    }
    toString() {
        return `v${this._major}${this._minor !== null ? '.' + this._minor : ''}${this._patch !== null ? '.' + this._patch : ''}${this._rc !== null ? 'rc' + this._rc : ''}`;
    }
}
