import test from 'node:test';
import assert from 'node:assert';
import { STVersion } from './STVersion.js';
test('test all', () => {
    const rawVersion = 'v1.3.8rc2';
    const v = new STVersion(rawVersion);
    let currentVersion = v.toString();
    assert.strictEqual(currentVersion, rawVersion);
    currentVersion = v.bump('major');
    assert.equal(currentVersion, 'v2.0.0');
    currentVersion = v.bump('minor');
    assert.equal(currentVersion, 'v2.1.0');
    currentVersion = v.bump('patch');
    assert.equal(currentVersion, 'v2.1.1');
    currentVersion = v.bump('rc');
    assert.equal(currentVersion, 'v2.1.1rc1');
    currentVersion = v.bump('rc');
    assert.equal(currentVersion, 'v2.1.1rc2');
    currentVersion = v.bump('rc');
    assert.equal(currentVersion, 'v2.1.1rc3');
    currentVersion = v.bump('patch');
    assert.equal(currentVersion, 'v2.1.2');
    currentVersion = v.bump('rc');
    assert.equal(currentVersion, 'v2.1.2rc1');
    currentVersion = v.bump('minor');
    assert.equal(currentVersion, 'v2.2.0');
    currentVersion = v.bump('major');
    assert.equal(currentVersion, 'v3.0.0');
    currentVersion = v.bump('minor');
    assert.equal(currentVersion, 'v3.1.0');
    currentVersion = v.bump('patch');
    assert.equal(currentVersion, 'v3.1.1');
    currentVersion = v.bump('rc');
    assert.equal(currentVersion, 'v3.1.1rc1');
    currentVersion = v.bump('minor');
    assert.equal(currentVersion, 'v3.2.0');
    currentVersion = v.bump('minor');
    assert.equal(currentVersion, 'v3.3.0');
    currentVersion = v.bump('rc');
    assert.equal(currentVersion, 'v3.3.0rc1');
    currentVersion = v.bump('patch');
    assert.equal(currentVersion, 'v3.3.1');
});
test('test major bump', () => {
    const rawVersion = 'v1.3.8rc2';
    const v = new STVersion(rawVersion);
    let currentVersion = v.bump('major');
    assert.equal(currentVersion, 'v2.0.0');
    currentVersion = v.bump('major');
    assert.equal(currentVersion, 'v3.0.0');
});
test('test minor bump', () => {
    const rawVersion = 'v1.3.8rc2';
    const v = new STVersion(rawVersion);
    let currentVersion = v.bump('minor');
    assert.equal(currentVersion, 'v1.4.0');
    currentVersion = v.bump('minor');
    assert.equal(currentVersion, 'v1.5.0');
});
test('test patch bump', () => {
    const rawVersion = 'v1.3.8rc2';
    const v = new STVersion(rawVersion);
    let currentVersion = v.bump('patch');
    assert.equal(currentVersion, 'v1.3.9');
    currentVersion = v.bump('patch');
    assert.equal(currentVersion, 'v1.3.10');
});
test('test rc bump', () => {
    const rawVersion = 'v1.3.8rc2';
    const v = new STVersion(rawVersion);
    let currentVersion = v.bump('rc');
    assert.equal(currentVersion, 'v1.3.8rc3');
    currentVersion = v.bump('rc');
    assert.equal(currentVersion, 'v1.3.8rc4');
});
test('test bump with no rc', () => {
    const rawVersion = 'v1.3.8';
    const v = new STVersion(rawVersion);
    let currentVersion = v.bump('rc');
    assert.equal(currentVersion, 'v1.3.8rc1');
    currentVersion = v.bump('rc');
    assert.equal(currentVersion, 'v1.3.8rc2');
});
test('test bump with no patch', () => {
    const rawVersion = 'v1.3';
    const v = new STVersion(rawVersion);
    let currentVersion = v.bump('patch');
    assert.equal(currentVersion, 'v1.3.1');
    currentVersion = v.bump('patch');
    assert.equal(currentVersion, 'v1.3.2');
});
test('test bump with no minor', () => {
    const rawVersion = 'v1';
    const v = new STVersion(rawVersion);
    let currentVersion = v.bump('minor');
    assert.equal(currentVersion, 'v1.1');
    currentVersion = v.bump('minor');
    assert.equal(currentVersion, 'v1.2');
});
test('test bump with no major', () => {
    const rawVersion = 'v0';
    const v = new STVersion(rawVersion);
    let currentVersion = v.bump('major');
    assert.equal(currentVersion, 'v1');
    currentVersion = v.bump('major');
    assert.equal(currentVersion, 'v2');
});
test('test bump with no major and no minor', () => {
    const rawVersion = 'v0.0';
    const v = new STVersion(rawVersion);
    let currentVersion = v.bump('minor');
    assert.equal(currentVersion, 'v0.1');
    currentVersion = v.bump('minor');
    assert.equal(currentVersion, 'v0.2');
});
test('test bump with no major and no minor and no patch', () => {
    const rawVersion = 'v0.0.0';
    const v = new STVersion(rawVersion);
    let currentVersion = v.bump('patch');
    assert.equal(currentVersion, 'v0.0.1');
    currentVersion = v.bump('patch');
    assert.equal(currentVersion, 'v0.0.2');
});
test('test bump with no major and no minor and no patch and no rc', () => {
    const rawVersion = 'v0.0.0';
    const v = new STVersion(rawVersion);
    let currentVersion = v.bump('rc');
    assert.equal(currentVersion, 'v0.0.0rc1');
    currentVersion = v.bump('rc');
    assert.equal(currentVersion, 'v0.0.0rc2');
});
test('test bump rc with no patch and no rc', () => {
    const rawVersion = 'v0.0';
    const v = new STVersion(rawVersion);
    let currentVersion = v.bump('rc');
    assert.equal(currentVersion, 'v0.0.0rc1');
    currentVersion = v.bump('rc');
    assert.equal(currentVersion, 'v0.0.0rc2');
});
test('test bump patch with no patch', () => {
    const rawVersion = 'v0.3';
    const v = new STVersion(rawVersion);
    let currentVersion = v.bump('patch');
    assert.equal(currentVersion, 'v0.3.1');
    currentVersion = v.bump('patch');
    assert.equal(currentVersion, 'v0.3.2');
});
test('test bump rc with no rc and no patch', () => {
    const rawVersion = 'v0.3';
    const v = new STVersion(rawVersion);
    let currentVersion = v.bump('rc');
    assert.equal(currentVersion, 'v0.3.0rc1');
    currentVersion = v.bump('rc');
    assert.equal(currentVersion, 'v0.3.0rc2');
});
